import { allArgOptions } from "../shared/options/args.js";
import {
  getExclusions
} from "../shared/options/exclusionKeys.js";
import { createRerunDirectorySuggestion } from "./createRerunDirectorySuggestion.js";
function getFirstMatchingArg(key) {
  return Object.keys(allArgOptions).find(
    (arg) => arg.replaceAll("-", "") === key.toLowerCase()
  );
}
const defaultValues = /* @__PURE__ */ new Map([["access", "public"]]);
function createRerunSuggestion(options) {
  const optionsNormalized = {
    ...options,
    email: void 0,
    ...options.email && {
      emailGitHub: options.email.github,
      emailNpm: options.email.npm
    },
    ...options.guide ? {
      guide: options.guide.href,
      guideTitle: options.guide.title
    } : { guide: void 0 },
    ...options.logo ? {
      logo: options.logo.src,
      logoAlt: options.logo.alt
    } : { logo: void 0 },
    ...options.offline && {
      skipAllContributorsApi: void 0,
      skipGitHubApi: void 0
    },
    directory: createRerunDirectorySuggestion(options)
  };
  const args = Object.entries(optionsNormalized).sort(
    ([a], [b]) => a === "base" ? -1 : b === "base" ? 1 : a.localeCompare(b)
  ).filter(
    ([key, value]) => getExclusions(options, optionsNormalized.base)[key] == void 0 && !!value && value !== defaultValues.get(key)
  ).map(([key, value]) => {
    return `--${getFirstMatchingArg(key)}${stringifyValue(value)}`;
  }).join(" ");
  return ["npx create-typescript-app", args].filter(Boolean).join(" ");
}
function stringifyValue(value) {
  if (Array.isArray(value)) {
    return stringifyValue(value.join(" "));
  }
  if (typeof value === "boolean" && value) {
    return "";
  }
  const valueStringified = `${value}`;
  return valueStringified.includes(" ") ? ` "${valueStringified}"` : ` ${valueStringified}`;
}
export {
  createRerunSuggestion
};
//# sourceMappingURL=createRerunSuggestion.js.map