import { $ } from "execa";
import { runCreateEnginePreset } from "../next/runCreateEnginePreset.js";
import {
  withSpinner,
  withSpinners
} from "../shared/cli/spinners.js";
import { createCleanupCommands } from "../shared/createCleanupCommands.js";
import { doesRepositoryExist } from "../shared/doesRepositoryExist.js";
import { isUsingCreateEngine } from "../shared/isUsingCreateEngine.js";
import { addToolAllContributors } from "../steps/addToolAllContributors.js";
import { clearLocalGitTags } from "../steps/clearLocalGitTags.js";
import { finalizeDependencies } from "../steps/finalizeDependencies.js";
import { initializeGitHubRepository } from "../steps/initializeGitHubRepository/index.js";
import { runCleanup } from "../steps/runCleanup.js";
import { writeReadme } from "../steps/writeReadme/index.js";
import { writeStructure } from "../steps/writing/writeStructure.js";
async function createWithOptions({ octokit, options }, repositoryDirectory) {
  process.chdir(repositoryDirectory);
  const $$ = $({ cwd: repositoryDirectory });
  if (isUsingCreateEngine()) {
    await withSpinner("Creating repository", async () => {
      await runCreateEnginePreset(options);
    });
    return { sentToGitHub: false };
  }
  await withSpinners("Creating repository structure", [
    [
      "Writing structure",
      async () => {
        await writeStructure(options);
      }
    ],
    [
      "Writing README.md",
      async () => {
        await writeReadme(options);
      }
    ]
  ]);
  if (!options.excludeAllContributors && !options.skipAllContributorsApi) {
    await withSpinner("Adding contributors to table", async () => {
      await addToolAllContributors(octokit, options);
    });
  }
  if (!options.skipInstall) {
    await withSpinner(
      "Installing packages",
      async () => finalizeDependencies(options)
    );
    await runCleanup(createCleanupCommands(options.bin), options.mode);
  }
  await withSpinner("Clearing any local Git tags", clearLocalGitTags);
  const sendToGitHub = octokit && await doesRepositoryExist(octokit, options);
  if (sendToGitHub) {
    await withSpinner("Initializing GitHub repository", async () => {
      await $$`git remote add origin https://github.com/${options.owner}/${options.repository}`;
      await $$`git add -A`;
      await $$`git commit --message ${"feat: initialized repo \u2728"} --no-gpg-sign`;
      await $$`git push -u origin main --force`;
      await initializeGitHubRepository(octokit, options);
    });
  }
  return { sentToGitHub: sendToGitHub };
}
export {
  createWithOptions
};
//# sourceMappingURL=createWithOptions.js.map