import { z } from 'zod';
import { StatusCode } from './codes.js';

interface AllContributorContributor {
    avatar_url: string;
    contributions: string[];
    login: string;
    name: string;
    profile: string;
}
interface AllContributorsData {
    contributors: AllContributorContributor[];
}
type OptionsAccess = "public" | "restricted";
type OptionsBase = "common" | "everything" | "minimal" | "prompt";
interface OptionsEmail {
    github: string;
    npm: string;
}
interface OptionsGuide {
    href: string;
    title: string;
}
interface OptionsLogo {
    alt: string;
    height?: number;
    src: string;
    width?: number;
}
interface PartialPackageData {
    author?: string | {
        email: string;
        name: string;
    };
    bin?: string;
    dependencies?: Record<string, string>;
    description?: string;
    devDependencies?: Record<string, string>;
    email?: string;
    engines?: {
        node?: string;
    };
    name?: string;
    repository?: string | {
        type: string;
        url: string;
    };
    scripts?: Record<string, string>;
    version?: string;
}
/**
 * All runtime options that may (or must) be specified for setup.
 */
interface Options {
    access: OptionsAccess;
    author?: string;
    base?: OptionsBase;
    bin?: string;
    description: string;
    directory: string;
    email: OptionsEmail;
    excludeAllContributors?: boolean;
    excludeBuild?: boolean;
    excludeCompliance?: boolean;
    excludeLintESLint?: boolean;
    excludeLintJSDoc?: boolean;
    excludeLintJson?: boolean;
    excludeLintKnip?: boolean;
    excludeLintMd?: boolean;
    excludeLintPackageJson?: boolean;
    excludeLintPackages?: boolean;
    excludeLintPerfectionist?: boolean;
    excludeLintRegexp?: boolean;
    excludeLintSpelling?: boolean;
    excludeLintStrict?: boolean;
    excludeLintStylistic?: boolean;
    excludeLintYml?: boolean;
    excludeReleases?: boolean;
    excludeRenovate?: boolean;
    excludeTemplatedBy?: boolean;
    excludeTests?: boolean;
    funding?: string;
    guide?: OptionsGuide;
    keywords?: string[];
    logo?: OptionsLogo;
    mode: Mode;
    offline?: boolean;
    owner: string;
    preserveGeneratedFrom?: boolean;
    repository: string;
    skipAllContributorsApi?: boolean;
    skipGitHubApi?: boolean;
    skipInstall?: boolean;
    skipRemoval?: boolean;
    skipRestore?: boolean;
    skipUninstall?: boolean;
    title: string;
}
/**
 * Options that might be suggested by how the user is running setup.
 */
type Mode = "create" | "initialize" | "migrate";
interface ModeResult {
    code: StatusCode;
    error?: string | z.ZodError<object>;
    options: Partial<Options>;
}
type ModeRunner = (args: string[], promptedOptions?: PromptedOptions) => Promise<ModeResult>;
interface PromptedOptions {
    /**
     * Directory for the repository, if it may differ from the repository name.
     */
    directory?: string;
    /**
     * Repository name, if it may differ from the current directory.
     */
    repository?: string;
}

export type { AllContributorContributor, AllContributorsData, Mode, ModeResult, ModeRunner, Options, OptionsAccess, OptionsBase, OptionsEmail, OptionsGuide, OptionsLogo, PartialPackageData, PromptedOptions };
